@@ -346,7 +346,7 @@ class TestCompleter(unittest.TestCase):
             suffixes = ["1", "2"]
             names = [prefix + s for s in suffixes]
             for n in names:
-                open(n, "w").close()
+                open(n, "w", encoding="utf-8").close()
 
             # Check simple completion
             c = ip.complete(prefix)[1]
@@ -365,7 +365,7 @@ class TestCompleter(unittest.TestCase):
             suffixes = ["1", "2"]
             names = [prefix + s for s in suffixes]
             for n in names:
-                open(n, "w").close()
+                open(n, "w", encoding="utf-8").close()
 
             # Check simple completion
             c = ip.complete(prefix)[1]
@@ -381,7 +381,7 @@ class TestCompleter(unittest.TestCase):
         ip = get_ipython()
         with TemporaryWorkingDirectory():
             name = "foo'bar"
-            open(name, "w").close()
+            open(name, "w", encoding="utf-8").close()
 
             # Don't escape Windows
             escaped = name if sys.platform == "win32" else "foo\\'bar"
@@ -475,6 +475,7 @@ class TestCompleter(unittest.TestCase):
             "encoding" in c.signature
         ), "Signature of function was not found by completer"
 
+    @pytest.mark.xfail(reason="Known failure on jedi<=0.18.0")
     def test_deduplicate_completions(self):
         """
         Test that completions are correctly deduplicated (even if ranges are not the same)
@@ -1261,3 +1262,14 @@ class TestCompleter(unittest.TestCase):
         _, matches = ip.complete(None, "test.meth(")
         self.assertIn("meth_arg1=", matches)
         self.assertNotIn("meth2_arg1=", matches)
+
+    def test_percent_symbol_restrict_to_magic_completions(self):
+        ip = get_ipython()
+        completer = ip.Completer
+        text = "%a"
+
+        with provisionalcompleter():
+            completer.use_jedi = True
+            completions = completer.completions(text, len(text))
+            for c in completions:
+                self.assertEqual(c.text[0], "%")
