@@ -3,21 +3,20 @@
 """
 import io
 import logging
-import sys
 import os.path
-from textwrap import dedent
+import platform
+import re
+import sys
 import traceback
 import unittest
-from unittest import mock
-
-import IPython.core.ultratb as ultratb
-from IPython.core.ultratb import ColorTB, VerboseTB, find_recursion
+from textwrap import dedent
 
+from tempfile import TemporaryDirectory
 
+from IPython.core.ultratb import ColorTB, VerboseTB
 from IPython.testing import tools as tt
 from IPython.testing.decorators import onlyif_unicode_paths
 from IPython.utils.syspathcontext import prepended_to_syspath
-from IPython.utils.tempdir import TemporaryDirectory
 
 file_1 = """1
 2
@@ -38,16 +37,12 @@ def recursionlimit(frames):
 
     def inner(test_function):
         def wrapper(*args, **kwargs):
-            _orig_rec_limit = ultratb._FRAME_RECURSION_LIMIT
-            ultratb._FRAME_RECURSION_LIMIT = 50
-
             rl = sys.getrecursionlimit()
             sys.setrecursionlimit(frames)
             try:
                 return test_function(*args, **kwargs)
             finally:
                 sys.setrecursionlimit(rl)
-                ultratb._FRAME_RECURSION_LIMIT = _orig_rec_limit
 
         return wrapper
 
@@ -62,7 +57,7 @@ class ChangedPyFileTest(unittest.TestCase):
         """
         with TemporaryDirectory() as td:
             fname = os.path.join(td, "foo.py")
-            with open(fname, "w") as f:
+            with open(fname, "w", encoding="utf-8") as f:
                 f.write(file_1)
             
             with prepended_to_syspath(td):
@@ -72,7 +67,7 @@ class ChangedPyFileTest(unittest.TestCase):
                 ip.run_cell("foo.f()")
             
             # Make the file shorter, so the line of the error is missing.
-            with open(fname, "w") as f:
+            with open(fname, "w", encoding="utf-8") as f:
                 f.write(file_2)
             
             # For some reason, this was failing on the *second* call after
@@ -96,7 +91,7 @@ class NonAsciiTest(unittest.TestCase):
         # Non-ascii directory name as well.
         with TemporaryDirectory(suffix=u'é') as td:
             fname = os.path.join(td, u"fooé.py")
-            with open(fname, "w") as f:
+            with open(fname, "w", encoding="utf-8") as f:
                 f.write(file_1)
             
             with prepended_to_syspath(td):
@@ -176,7 +171,7 @@ class IndentationErrorTest(unittest.TestCase):
         
         with TemporaryDirectory() as td:
             fname = os.path.join(td, "foo.py")
-            with open(fname, "w") as f:
+            with open(fname, "w", encoding="utf-8") as f:
                 f.write(indentationerror_file)
             
             with tt.AssertPrints("IndentationError"):
@@ -192,10 +187,6 @@ se_file_2 = """7/
 """
 
 class SyntaxErrorTest(unittest.TestCase):
-    def test_syntaxerror_without_lineno(self):
-        with tt.AssertNotPrints("TypeError"):
-            with tt.AssertPrints("line unknown"):
-                ip.run_cell("raise SyntaxError()")
 
     def test_syntaxerror_no_stacktrace_at_compile_time(self):
         syntax_error_at_compile_time = """
@@ -229,14 +220,14 @@ bar()
     def test_changing_py_file(self):
         with TemporaryDirectory() as td:
             fname = os.path.join(td, "foo.py")
-            with open(fname, 'w') as f:
+            with open(fname, "w", encoding="utf-8") as f:
                 f.write(se_file_1)
 
             with tt.AssertPrints(["7/", "SyntaxError"]):
                 ip.magic("run " + fname)
 
             # Modify the file
-            with open(fname, 'w') as f:
+            with open(fname, "w", encoding="utf-8") as f:
                 f.write(se_file_2)
 
             # The SyntaxError should point to the correct line
@@ -252,12 +243,17 @@ bar()
             with tt.AssertPrints('QWERTY'):
                 ip.showsyntaxerror()
 
+import sys
 
-class MemoryErrorTest(unittest.TestCase):
-    def test_memoryerror(self):
-        memoryerror_code = "(" * 200 + ")" * 200
-        with tt.AssertPrints("MemoryError"):
-            ip.run_cell(memoryerror_code)
+if sys.version_info < (3, 9) and platform.python_implementation() != "PyPy":
+    """
+    New 3.9 Pgen Parser does not raise Memory error, except on failed malloc.
+    """
+    class MemoryErrorTest(unittest.TestCase):
+        def test_memoryerror(self):
+            memoryerror_code = "(" * 200 + ")" * 200
+            with tt.AssertPrints("MemoryError"):
+                ip.run_cell(memoryerror_code)
 
 
 class Python3ChainedExceptionsTest(unittest.TestCase):
@@ -350,45 +346,24 @@ def r3o2():
         ip.run_cell(self.DEFINITIONS)
 
     def test_no_recursion(self):
-        with tt.AssertNotPrints("frames repeated"):
+        with tt.AssertNotPrints("skipping similar frames"):
             ip.run_cell("non_recurs()")
 
-    @recursionlimit(150)
+    @recursionlimit(200)
     def test_recursion_one_frame(self):
-        with tt.AssertPrints("1 frames repeated"):
+        with tt.AssertPrints(re.compile(
+            r"\[\.\.\. skipping similar frames: r1 at line 5 \(\d{2,3} times\)\]")
+        ):
             ip.run_cell("r1()")
 
-    @recursionlimit(150)
+    @recursionlimit(160)
     def test_recursion_three_frames(self):
-        with tt.AssertPrints("3 frames repeated"):
+        with tt.AssertPrints("[... skipping similar frames: "), \
+                tt.AssertPrints(re.compile(r"r3a at line 8 \(\d{2} times\)"), suppress=False), \
+                tt.AssertPrints(re.compile(r"r3b at line 11 \(\d{2} times\)"), suppress=False), \
+                tt.AssertPrints(re.compile(r"r3c at line 14 \(\d{2} times\)"), suppress=False):
             ip.run_cell("r3o2()")
 
-    @recursionlimit(150)
-    def test_find_recursion(self):
-        captured = []
-        def capture_exc(*args, **kwargs):
-            captured.append(sys.exc_info())
-        with mock.patch.object(ip, 'showtraceback', capture_exc):
-            ip.run_cell("r3o2()")
-
-        self.assertEqual(len(captured), 1)
-        etype, evalue, tb = captured[0]
-        self.assertIn("recursion", str(evalue))
-
-        records = ip.InteractiveTB.get_records(tb, 3, ip.InteractiveTB.tb_offset)
-        for r in records[:10]:
-            print(r[1:4])
-
-        # The outermost frames should be:
-        # 0: the 'cell' that was running when the exception came up
-        # 1: r3o2()
-        # 2: r3o1()
-        # 3: r3a()
-        # Then repeating r3b, r3c, r3a
-        last_unique, repeat_length = find_recursion(etype, evalue, records)
-        self.assertEqual(last_unique, 2)
-        self.assertEqual(repeat_length, 3)
-
 
 #----------------------------------------------------------------------------
 
@@ -432,35 +407,3 @@ def test_handlers():
     except:
         handler(*sys.exc_info())
     buff.write('')
-
-from IPython.testing.decorators import skipif
-
-class TokenizeFailureTest(unittest.TestCase):
-    """Tests related to https://github.com/ipython/ipython/issues/6864."""
-
-    # that appear to test that we are handling an exception that can be thrown
-    # by the tokenizer due to a bug that seem to have been fixed in 3.8, though
-    # I'm unsure if other sequences can make it raise this error. Let's just
-    # skip in 3.8 for now
-    @skipif(sys.version_info > (3,8))
-    def testLogging(self):
-        message = "An unexpected error occurred while tokenizing input"
-        cell = 'raise ValueError("""a\nb""")'
-
-        stream = io.StringIO()
-        handler = logging.StreamHandler(stream)
-        logger = logging.getLogger()
-        loglevel = logger.level
-        logger.addHandler(handler)
-        self.addCleanup(lambda: logger.removeHandler(handler))
-        self.addCleanup(lambda: logger.setLevel(loglevel))
-
-        logger.setLevel(logging.INFO)
-        with tt.AssertNotPrints(message):
-            ip.run_cell(cell)
-        self.assertNotIn(message, stream.getvalue())
-
-        logger.setLevel(logging.DEBUG)
-        with tt.AssertNotPrints(message):
-            ip.run_cell(cell)
-        self.assertIn(message, stream.getvalue())
