@@ -1,9 +1,8 @@
 """Simple example using doctests.
 
 This file just contains doctests both using plain python and IPython prompts.
-All tests should be loaded by nose.
+All tests should be loaded by Pytest.
 """
-from __future__ import print_function
 
 def pyfunc():
     """Some pure python tests...
@@ -25,10 +24,21 @@ def pyfunc():
     return 'pyfunc'
 
 
-def ipyfunc2():
-    """Some pure python tests...
+def ipyfunc():
+    """Some IPython tests...
 
-    >>> 1+1
-    2
+    In [1]: ipyfunc()
+    Out[1]: 'ipyfunc'
+
+    In [2]: import os
+
+    In [3]: 2+3
+    Out[3]: 5
+
+    In [4]: for i in range(3):
+       ...:     print(i, end=' ')
+       ...:     print(i+1, end=' ')
+       ...:
+    Out[4]: 0 1 1 2 2 3
     """
-    return 'pyfunc2'
+    return "ipyfunc"
