@@ -390,9 +390,8 @@ class ApiDocWriter(object):
             if not api_str:
                 continue
             # write out to file
-            outfile = os.path.join(outdir,
-                                   m + self.rst_extension)
-            with open(outfile, 'wt') as fileobj:
+            outfile = os.path.join(outdir, m + self.rst_extension)
+            with open(outfile, "wt", encoding="utf-8") as fileobj:
                 fileobj.write(api_str)
             written_modules.append(m)
         self.written_modules = written_modules
@@ -444,7 +443,7 @@ class ApiDocWriter(object):
             relpath = outdir.replace(relative_to + os.path.sep, '')
         else:
             relpath = outdir
-        with open(path,'wt') as idx:
+        with open(path, "wt", encoding="utf-8") as idx:
             w = idx.write
             w('.. AUTO-GENERATED FILE -- DO NOT EDIT!\n\n')
             w('.. autosummary::\n'
