@@ -36,7 +36,7 @@ repo_root = os.path.dirname(os.path.abspath(__file__))
 
 def execfile(fname, globs, locs=None):
     locs = locs or globs
-    with open(fname) as f:
+    with open(fname, encoding="utf-8") as f:
         exec(compile(f.read(), fname, "exec"), globs, locs)
 
 # A little utility we'll need below, since glob() does NOT allow you to do
@@ -336,10 +336,13 @@ def git_prebuild(pkg_dir, build_cmd=build_py):
                 os.remove(out_pth)
             except (IOError, OSError):
                 pass
-            with open(out_pth, 'w') as out_file:
-                out_file.writelines([
-                    '# GENERATED BY setup.py\n',
-                    'commit = u"%s"\n' % repo_commit,
-                ])
+            with open(out_pth, "w", encoding="utf-8") as out_file:
+                out_file.writelines(
+                    [
+                        "# GENERATED BY setup.py\n",
+                        'commit = u"%s"\n' % repo_commit,
+                    ]
+                )
+
     return MyBuildPy
 
